#!/bin/sh -e

VERSION=$2
TAR=../modello1.4_$VERSION.orig.tar.gz
DIR=modello-$VERSION
TAG=modello-$2

svn export https://svn.codehaus.org/modello/tags/$TAG $DIR
rm -rf $DIR/modello-maven-plugin
rm -rf $DIR/modello-test
tar -c -z -f $TAR $DIR
rm -rf $DIR ../$TAG

# move to directory 'tarballs'
if [ -r .svn/deb-layout ]; then
  . .svn/deb-layout
  mv $TAR $origDir
  echo "moved $TAR to $origDir"
fi
